@@ -8,22 +8,26 @@
 
 PackageDependsStatus PackageDependsStatus::ok()
 {
+    // qCDebug(appLog) << "Creating OK status";
     return {Pkg::DependsStatus::DependsOk, QString()};
 }
 
 PackageDependsStatus PackageDependsStatus::available(const QString &package)
 {
+    // qCDebug(appLog) << "Creating AVAILABLE status for package:" << package;
     // 修复卸载p7zip导致deepin-wine-helper被卸载的问题，Available 添加packageName
     return {Pkg::DependsStatus::DependsAvailable, package};
 }
 
 PackageDependsStatus PackageDependsStatus::_break(const QString &package)
 {
+    qCDebug(appLog) << "Creating BREAK status for package:" << package;
     return {Pkg::DependsStatus::DependsBreak, package};
 }
 
 PackageDependsStatus PackageDependsStatus::_prohibit(const QString &package)
 {
+    qCDebug(appLog) << "Creating PROHIBIT status for package:" << package;
     return {Pkg::DependsStatus::DependsBreak, package};
 }
 
@@ -37,10 +41,12 @@ PackageDependsStatus::PackageDependsStatus(const int status, const QString &pack
     : status(status)
     , package(package)
 {
+    qCDebug(appLog) << "Creating PackageDependsStatus with status:" << status << "package:" << package;
 }
 
 PackageDependsStatus &PackageDependsStatus::operator=(const PackageDependsStatus &other)
 {
+    // qCDebug(appLog) << "Assigning PackageDependsStatus from package:" << other.package;
     status = other.status;
     package = other.package;
 
@@ -49,6 +55,7 @@ PackageDependsStatus &PackageDependsStatus::operator=(const PackageDependsStatus
 
 PackageDependsStatus PackageDependsStatus::max(const PackageDependsStatus &other)
 {
+    // qCDebug(appLog) << "Comparing PackageDependsStatus with status:" << other.status << "for package:" << other.package;
     if (other.status > status) {
         qCDebug(appLog) << "Upgrading status from" << status << "to" << other.status << "for package:" << other.package;
         *this = other;
@@ -59,16 +66,20 @@ PackageDependsStatus PackageDependsStatus::max(const PackageDependsStatus &other
 
 PackageDependsStatus PackageDependsStatus::maxEq(const PackageDependsStatus &other)
 {
-    if (other.status >= status)
+    // qCDebug(appLog) << "Comparing PackageDependsStatus with status:" << other.status << "for package:" << other.package;
+    if (other.status >= status) {
+        // qCDebug(appLog) << "Upgrading status from" << status << "to" << other.status << "for package:" << other.package;
         *this = other;
+    }
 
     return *this;
 }
 
 PackageDependsStatus PackageDependsStatus::min(const PackageDependsStatus &other)
 {
+    // qCDebug(appLog) << "Comparing PackageDependsStatus with status:" << other.status << "for package:" << other.package;
     if (other.status < status) {
-        qCDebug(appLog) << "Downgrading status from" << status << "to" << other.status << "for package:" << other.package;
+        // qCDebug(appLog) << "Downgrading status from" << status << "to" << other.status << "for package:" << other.package;
         *this = other;
     }
 
@@ -77,14 +88,18 @@ PackageDependsStatus PackageDependsStatus::min(const PackageDependsStatus &other
 
 PackageDependsStatus PackageDependsStatus::minEq(const PackageDependsStatus &other)
 {
-    if (other.status <= status)
+    // qCDebug(appLog) << "Comparing PackageDependsStatus with status:" << other.status << "for package:" << other.package;
+    if (other.status <= status) {
+        // qCDebug(appLog) << "Downgrading status from" << status << "to" << other.status << "for package:" << other.package;
         *this = other;
+    }
 
     return *this;
 }
 
 bool PackageDependsStatus::isBreak() const
 {
+    // qCDebug(appLog) << "Checking if package is break";
     bool result = status == Pkg::DependsStatus::DependsBreak;
     if (result) {
         qCDebug(appLog) << "Package" << package << "has broken dependencies";
@@ -94,17 +109,23 @@ bool PackageDependsStatus::isBreak() const
 
 bool PackageDependsStatus::isAuthCancel() const
 {
-    return status == Pkg::DependsStatus::DependsAuthCancel;
+    bool result = status == Pkg::DependsStatus::DependsAuthCancel;
+    // qCDebug(appLog) << "Checking auth cancel status:" << result;
+    return result;
 }
 
 bool PackageDependsStatus::isAvailable() const
 {
-    return status == Pkg::DependsStatus::DependsAvailable;
+    bool result = status == Pkg::DependsStatus::DependsAvailable;
+    // qCDebug(appLog) << "Checking available status:" << result << "for package:" << package;
+    return result;
 }
 
 bool PackageDependsStatus::isProhibit() const
 {
-    return status == Pkg::DependsStatus::Prohibit;
+    bool result = status == Pkg::DependsStatus::Prohibit;
+    // qCDebug(appLog) << "Checking prohibit status:" << result << "for package:" << package;
+    return result;
 }
 
 bool PackageDependsStatus::canInstall() const
@@ -116,5 +137,7 @@ bool PackageDependsStatus::canInstall() const
 
 bool PackageDependsStatus::canInstallCompatible() const
 {
-    return status == Pkg::CompatibleNotInstalled;
+    bool result = status == Pkg::CompatibleNotInstalled;
+    // qCDebug(appLog) << "Checking compatible install status:" << result << "for package:" << package;
+    return result;
 }
